import 'package:fis_jsonrpc/rpc.dart';
import 'package:fis_ui/types/widget_builders.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vitalapp/components/table/table_column.dart';
import 'package:vitalapp/managers/interfaces/appointment.dart';
import 'package:vitalapp/managers/interfaces/patient.dart';
import 'package:vitalapp/managers/interfaces/registration.dart';
import 'package:vitalapp/pages/medical_checkup_station/registration/state/list.dart';
import 'package:vitalapp/store/store.dart';

/// 体检表格控制器
class HealthCheckListController extends GetxController {
  final appointmentManager = Get.find<IAppointmentManager>();
  final registrationManager = Get.find<IRegistrationManager>();
  final state = ListState();

  String? checkKey = "HEIBasic";

  HealthCheckListController({this.checkKey});

  /// 登记
  ResidentModel resident = ResidentModel(
    idNumber: '',
  );

  /// 手动填写的病人名字
  PatientDTO? patientInfo = PatientDTO();

  /// 预约列表
  List<ResidentModel> residentList = [];

  /// 预约列表的总数
  int appointmentModelListLength = 0;

  /// 当前列表选中的
  int currectSelected = -1;

  /// 表格loading
  bool tableLoading = true;

  /// 当前表格页数
  int currPageIndex = 1;

  /// 当前检测详情
  List<List<String>>? tableData = null;

  /// 中医保健指导
  MapEntry<String, dynamic>? healthGuidance = null;

  Future<void> getRegisterInfoPage({
    int? pageSize = 10,
    int? pageIndex = 1,
    String? keyword = "",
    DateTime? startTime,
    DateTime? endTime,
  }) async {
    tableLoading = true;
    currPageIndex = pageIndex!;
    currectSelected = -1;
    var result = await registrationManager.getRegisterInfoPageAsync(
      pageSize: pageSize,
      pageIndex: pageIndex,
      keyword: keyword,
      startTime: startTime,
      endTime: endTime,
    );

    List<ResidentModel> _residentList = [];
    if (result?.pageData != null) {
      for (RegisterInfoDTO i in result!.pageData!) {
        _residentList.add(
          ResidentModel(
            name: i.name ?? '',
            idNumber: i.iDCardNo ?? '',
            homeAddress: i.adress,
            age: null,
            physicalExamNumber: i.physicalExamNumber,
            phone: i.phone,
          ),
        );
      }
      appointmentModelListLength = result.totalCount;
    }

    residentList = _residentList;
    tableLoading = false;
    update(["healthCheck_table"]);
    update(["healthCheck_table_pagination"]);
  }

  /// 登记列表表头
  List<TableColumn<ResidentModel>> buildTableColumns(
      ValueCallback<ResidentModel> onRowTap) {
    var textStyle = TextStyle(
      fontSize: 16,
      overflow: TextOverflow.ellipsis,
    );
    return <TableColumn<ResidentModel>>[
      TableColumn<ResidentModel>(
        headerText: "体检号",
        maxWidth: 150,
        render: (rowData, index) => Container(
          padding: const EdgeInsets.symmetric(vertical: 16),
          child: Text(
            rowData.physicalExamNumber ?? '',
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "姓名",
        // maxWidth: 100,
        render: (rowData, index) => Center(
          child: Text(
            rowData.name ?? '',
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "身份证号",
        // maxWidth: 200,
        render: (rowData, index) => Center(
          child: Text(
            rowData.idNumber,
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "手机号",
        render: (rowData, index) => Center(
          child: Text(
            rowData.phone ?? '',
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "操作",
        maxWidth: 150,
        render: (rowData, index) => Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            TextButton(
              onPressed: () async {
                await changeHeartCheck(rowData);
                onRowTap.call(rowData);
              },
              child: Text(
                checkKey == "HEITCMC" ? "检测" : "检查",
              ),
            ),
          ],
        ),
      ),
    ];
  }

  Future<void> changeHeartCheck(ResidentModel resident) async {
    final _patientManager = Get.find<IPatientManager>();

    RegisterPersonInfoDTO? registerPersonInfo =
        await _patientManager.getRegisterPersonInfoByPhysicalExamNumberAsync(
      physicalExamNumber: resident.physicalExamNumber ?? '',
    );
    PatientDTO? patientInfo = PatientDTO();
    if (registerPersonInfo != null &&
        registerPersonInfo.physicalExamNumber != null) {
      patientInfo.code = registerPersonInfo.code;
      patientInfo.patientName = registerPersonInfo.name;
      Store.user.currentSelectRegisterPersonInfo = registerPersonInfo;
      Store.user.currentSelectPatientInfo = patientInfo;
    }

    /// 【TODO】 需要根据体检号码看是否有体检
    // List<ExamDTO>? examList = await controller.registrationManager
    //     .getExamListByPhysicalExamNumberAsync(
    //   physicalExamNumber: resident.physicalExamNumber ?? "",
    // );
    // print(examList?.first.examData);
  }

  _initData() async {
    var now = DateTime.now();
    var startTime = new DateTime(now.year, now.month, now.day);
    var endTime = startTime.add(Duration(hours: 23, minutes: 59, seconds: 59));
    await getRegisterInfoPage(startTime: startTime, endTime: endTime);
  }

  void onTap() {}

  // @override
  // void onInit() {
  //   super.onInit();
  // }

  @override
  void onReady() {
    super.onReady();
    _initData();
  }

  // @override
  // void onClose() {
  //   super.onClose();
  // }
}
