import 'package:fis_jsonrpc/rpc.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vitalapp/components/table/table_column.dart';
import 'package:vitalapp/managers/interfaces/appointment.dart';
import 'package:vitalapp/managers/interfaces/registration.dart';
import 'package:vitalapp/pages/medical_checkup_station/registration/state/list.dart';

/// 心电表格控制器
class HeartCheckListController extends GetxController {
  final appointmentManager = Get.find<IAppointmentManager>();
  final registrationManager = Get.find<IRegistrationManager>();
  final state = ListState();

  HeartCheckListController() {}

  /// 登记
  ResidentModel resident = ResidentModel(
    idNumber: '',
  );

  /// 手动填写的病人名字
  PatientDTO? patientInfo = PatientDTO();

  /// 预约列表
  List<ResidentModel> residentList = [];

  /// 预约列表的总数
  int appointmentModelListLength = 0;

  /// 表格loading
  bool tableLoading = true;

  /// 当前表格页数
  int currPageIndex = 1;

  /// 当前检测详情
  List<List<String>>? tableData = null;

  Future<void> getRegisterInfoPage({
    int? pageSize = 10,
    int? pageIndex = 1,
    String? keyword = "",
  }) async {
    tableLoading = true;
    currPageIndex = pageIndex!;

    var result = await registrationManager.getElectrocardiogramRecordPageAsync(
      pageSize: pageSize,
      pageIndex: pageIndex,
      keyword: keyword,
    );

    List<ResidentModel> _residentList = [];
    if (result?.pageData != null) {
      for (ElectrocardiogramRecord i in result!.pageData!) {
        _residentList.add(
          ResidentModel(
            name: i.patientName ?? '',
            idNumber: i.cardNo ?? '',
            homeAddress: i.patientAddress,
            age: null,
            physicalExamNumber: i.physicalExamNumber,
            // phone: "11111",
          ),
        );
      }
      appointmentModelListLength = result.totalCount;
    }

    residentList = _residentList;
    tableLoading = false;
    update(["heartCheck_table"]);
    update(["heartCheck_table_pagination"]);
  }

  /// 登记列表表头
  List<TableColumn<ResidentModel>> buildTableColumns() {
    var textStyle = TextStyle(
      fontSize: 16,
      overflow: TextOverflow.ellipsis,
    );
    return <TableColumn<ResidentModel>>[
      TableColumn<ResidentModel>(
        headerText: "体检号",
        maxWidth: 150,
        render: (rowData, index) => Container(
          padding: const EdgeInsets.symmetric(vertical: 16),
          child: Text(
            rowData.physicalExamNumber ?? '',
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "姓名",
        // maxWidth: 100,
        render: (rowData, index) => Center(
          child: Text(
            rowData.name ?? '',
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "身份证号",
        // maxWidth: 200,
        render: (rowData, index) => Center(
          child: Text(
            rowData.idNumber,
            style: textStyle,
          ),
        ),
      ),
      TableColumn<ResidentModel>(
        headerText: "手机号",
        render: (rowData, index) => Center(
          child: Text(
            rowData.phone ?? '',
            style: textStyle,
          ),
        ),
      ),
    ];
  }

  _initData() async {
    await getRegisterInfoPage();
  }

  void onTap() {}

  // @override
  // void onInit() {
  //   super.onInit();
  // }

  @override
  void onReady() {
    super.onReady();
    _initData();
  }

  // @override
  // void onClose() {
  //   super.onClose();
  // }
}
